import React, { useEffect, useRef, useState } from 'react'
import {
  postTaProject,
  putTaProject,
  getTaProjectId,
} from '@/services/taProject'
import { getTaCustom } from '@/services/taCustom'
import Page from '@/components/Page'
import { Button, Card, Row, Col } from 'antd'
import {
  ProForm,
  ProFormDateTimeRangePicker,
  ProFormMoney,
  ProFormSelect,
  ProFormText,
  ProFormTextArea,
} from '@ant-design/pro-components'
import { formItemLayout, tailFormItemLayout } from '@/utils/form'
import { useNavigate, useSearchParams } from 'react-router-dom'
import moment from 'moment'

export default (props) => {
  const formRef = useRef()
  const navigate = useNavigate()

  const [params] = useSearchParams()
  const id = params.get('id')
  const [customSelect, setCustomSelect] = useState()

  useEffect(() => {
    if (id) {
      getTaProjectId(id).then((res) => {
        formRef.current?.setFieldsValue({
          ...res,
          time: [moment(res.startTime), moment(res.endTime)],
        })
      })
    }

    //所属客户下拉
    getTaCustom().then((res) => {
      setCustomSelect(
        res.records?.map(
          (x) =>
            ({
              label: x.customName,
              value: x.customId,
            } || [])
        )
      )
    })
  }, [])
  const onFinish = (values) => {
    const data = {
      ...values,
      startTime: values.time[0],
      endTime: values.time[1],
    }
    console.log(data)
    if (!id) {
      postTaProject(data).then((res) => {
        navigate(-1)
      })
    } else if (id) {
      putTaProject(id, data).then((res) => {
        navigate(-1)
      })
    }
  }
  return (
    <Page>
      <Card>
        <ProForm
          formRef={formRef}
          onFinish={onFinish}
          layout="horizontal"
          {...formItemLayout}
          submitter={{
            render: (_, doms) => [
              // doms.find((dom) => dom.props?.children === '提交'),
              <Row>
                <Col offset={6}>
                  <Button type="primary" htmlType="submit">
                    提交
                  </Button>
                </Col>
                <Col offset={1}>
                  <Button onClick={() => navigate(-1)}>返回</Button>
                </Col>
              </Row>,
            ],
          }}
        >
          <ProFormText name="partyA" label="甲方联系人" />
          <ProFormText name="partyAName" label="甲方名称" />
          <ProFormText name="partyB" label="乙方联系人" />
          <ProFormText name="partyBName" label="乙方名称" />
          <ProFormText name="projectName" label="项目名称" />
          <ProFormTextArea name="introduction" label="项目简介" />
          <ProFormDateTimeRangePicker name="time" label="工作周期" />
          <ProFormMoney name="quotation" label="合同报价" />
          <ProFormMoney name="receivedMoney" label="已收款" />
          <ProFormMoney name="invoicedMoney" label="已开票额" />
          <ProFormSelect
            name="stageName"
            label="阶段名称"
            options={[
              { label: '未开始', value: '0' },
              { label: '处理中', value: '1' },
              { label: '已完成', value: '2' },
            ]}
          />
          <ProFormSelect
            name="status"
            label="项目状态"
            options={[
              { label: '禁用', value: 0 },
              { label: '正常', value: 1 },
            ]}
          />
          <ProFormSelect
            options={customSelect}
            name="customId"
            label="所属客户"
          />
        </ProForm>
      </Card>
    </Page>
  )
}
